﻿using System;
using System.Net;
using System.Net.Security;
using System.Text;
using System.Web;
using System.Web.UI;
using ActiveReports.Server.Documents;
using ActiveReports.Server.Management;
using ActiveReports.Server.Management.Controls;
using ActiveReports.Server.Management.Resources;
using ActiveReports.Server.ReportControls;
using Newtonsoft.Json;

public partial class Default1 : Page
{
	private UiSetting _uiSettings;

	static Default1()
	{
		ServicePointManager.ServerCertificateValidationCallback += (sender, certificate, chain, sslPolicyErrors) => true;
	}

	protected void Page_Load(object sender, EventArgs e)
	{
		GetUiSetting();
		var action = ReportAction;

		var customTitle = string.Empty;
		if (_uiSettings != null)
		{
			var siteSettings = IsPortal ? _uiSettings.PortalSiteSettings : _uiSettings.AdminSiteSettings;
			customTitle = siteSettings != null && _uiSettings.Enabled ? siteSettings.Title : null;
		}				
		Page.Title = GetPageTitle(action, customTitle);

		if ((action == ReportAction.Create && string.IsNullOrEmpty(ModelName))
			|| (action != ReportAction.Create && string.IsNullOrEmpty(ReportId)))
		{
			Response.Redirect("/");
		}		
	}

	private void GetUiSetting()
	{
		using (var client = new WebClient {Encoding = Encoding.UTF8})
		{
			var scheme = HttpContext.Current.Request.Url.Scheme + "://";
			var siteUrl = HttpContext.Current.Request.Url.Authority;
			var applicationPath = HttpContext.Current.Request.ApplicationPath;
			client.Headers.Add("AuthToken", SecurityToken);
			var strResult = client.DownloadString(scheme + siteUrl + applicationPath + "/api/settings/ui");
			_uiSettings = JsonConvert.DeserializeObject<UiSetting>(strResult);
		}
	}

	protected override void OnPreRender(EventArgs e)
	{
		base.OnPreRender(e);
		Page.DataBind();
	}

	public string ReportId { get { return Request.Params["ReportId"]; } }
	public string ReportName { get { return Request.Params["ReportName"]; } }
	public string ModelName { get { return Request.Params["ModelName"]; } }
	public string SnapshotId { get { return Request.Params["SnapshotId"]; } }
	public bool IsPortal { get { return Request.Params["portal"] == "1"; } }

	public ReportAction ReportAction
	{
		get
		{
			ReportAction value;
			return Enum.TryParse(Request.Params["ReportAction"], out value) ? value : ReportAction.Design;
		}
	}

	public static bool IsHtml5PreviewMode  { get { return SiteSettings.PreviewMode == SiteSettings.PreviewModes.HTML5; } }
	public static bool IsJSViewerPreviewMode { get { return SiteSettings.PreviewMode == SiteSettings.PreviewModes.JSViewer; } }
	public bool IncludeDesigner { get { return ReportAction != ReportAction.Preview || SiteSettings.PreviewMode == SiteSettings.PreviewModes.Flash; } }

	public string SecurityToken
	{
		get
		{
			var fromPortal = !string.IsNullOrEmpty(Request.Params["portal"]);
			var cookie = Request.Cookies[fromPortal ? AuthCookies.ReportPortal : AuthCookies.AdminPortal];
			return cookie != null ? Uri.UnescapeDataString(cookie.Value ?? "") : null;
		}
	}

	protected DesignerElements HiddenElements
	{
		get
		{
			var helpLink = DesignerElements.None;
			var feedback = DesignerElements.None;
			if (_uiSettings != null && _uiSettings.Enabled)
			{
				helpLink = _uiSettings.CommonSiteSettings.ShowHelp ? DesignerElements.None : DesignerElements.HelpButton;
				feedback = _uiSettings.CommonSiteSettings.ShowSendFeedback ? DesignerElements.None : DesignerElements.FeedbackButton;
			}
			return helpLink | feedback;
		}
	}

	protected string DesignerHelpPath
	{
		get
		{
			return _uiSettings != null && _uiSettings.Enabled ? _uiSettings.CommonSiteSettings.HelpUrl : null;
		}
	}

	private static string GetPageTitle(ReportAction action, string title)
	{
		if (string.IsNullOrEmpty(title))
			title = Portal.TitleDefault;

		switch (action)
		{
			case ReportAction.Design:
			case ReportAction.Create:
				return title + Portal.TitleSufixDesign;
			case ReportAction.Preview:
				return title + Portal.TitleSufixPreview;
			default:
				return Portal.TitleDefault;
		}
	}
}
